require('dotenv/config');

const fs = require('fs');
const path = require('path');
const basename = path.basename(__filename);

const Sequelize = require('sequelize');

const env = process.env.NODE_ENV || 'development';

const config = require('../database')[env];
const sequelize = new Sequelize(config.database, config.username, config.password, config);

sequelize.authenticate().then(()=> {
  console.log('Database connection has been established successfully.');
}).catch((error)=> {
  console.error('Unable to connect to the database:', error);
});

fs
  .readdirSync(__dirname)
  .filter(file => {
    return (file.indexOf('.') !== 0) && (file !== basename) && (file.slice(-3) === '.js');
  })
  .forEach(file => {
    require(path.join(__dirname, file))(sequelize, Sequelize.DataTypes);
  });

module.exports = sequelize;
