/**
 * trial.ts
 * Copyright (C) 2021 Sanar
 *
 * @author Edgard Leal <edgard.leal@sanar.com>
 * @module trial.ts
 */

import express from 'express';
import { checkSchema, ValidationChain } from 'express-validator';
import { defaultMiddleware } from '../../middlewares/default.middleware';
import { TrialController } from '../../../controllers/trial.controller';

const router = express.Router();

const trialController = TrialController.getInstance();


const createLinkValidator: ValidationChain[] = checkSchema({
  user_id: {
    isString: true,
    isLength: {
      errorMessage: 'o campo user_id deve ter 24 caracteres',
      options: {
        max: 24,
        min: 24,
      },
    },
  },
  course_slug: {
    isString: true,
    isLength: {
      errorMessage: 'o campo course_slug deve ser informado',
      options: {
        max: 255,
        min: 2,
      },
    },
  },
});

router.post(
  '/link',
  createLinkValidator,
  defaultMiddleware(trialController.createSharableLink.bind(trialController)),
);

export { router };
