const { rest } = require('msw');
require('dotenv/config');

const ecommerceAPIURL = process.env.SANAR_ECOMMERCE_API_URL;
const { SANARLINK_URL } = process.env;

const handlers = [
  rest.get(/.*api.php.*/, (_, res, ctx) => res(
    ctx.status(200),
    ctx.json(require('../../../tests/mocks/msw/json/sanarlink/link_response.json')),
  )),
  rest.post(`${ecommerceAPIURL}/affiliates`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/ecommerce/insert-affiliate.ok.json')),
    );
  }),
  rest.post(`${ecommerceAPIURL}/coupon`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/ecommerce/insert-affiliate-coupon.ok.json')),
    );
  }),
  rest.get(`${ecommerceAPIURL}/coupon/:code`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/ecommerce/coupon.ok.json')),
    );
  }),
  rest.get(`${ecommerceAPIURL}/coupon/affiliate/:id`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/ecommerce/affiliate-coupons.ok.json')),
    );
  }),
  rest.get(`${ecommerceAPIURL}/coupon/:code/usage-resmed`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/ecommerce/list-coupon-usage.ok.json')),
    );
  }),
  rest.get(`${process.env.WALLETS_URL}/customers`, (req, res, ctx) => {
    return res(
      ctx.status(200),
      ctx.json(require('./json/payments/find-customer.json')),
    );
  }),
  rest.get(`${process.env.SUBSCRIPTIONS_URL}/subscriptions`, (req, res, ctx) => {
    const filter = req.url.searchParams.get('where') || '{}';
    const filterObject = JSON.parse(filter);
    const { metadata } = filterObject;
    if (metadata && (metadata.origin || '').indexOf('curso_com_erro') > -1) {
      return res(
        ctx.status(500),
        ctx.json(require('./json/payments/list-customer-subscriptions.json')),
      );
    }
    return res(
      ctx.status(200),
      ctx.json(require('./json/payments/list-customer-subscriptions.json')),
    );
  }),
];

module.exports = handlers;
